import axios from "axios";
import { firebase } from "./firebase";
import { get } from "svelte/store";
function createApi() {
    let fb = get(firebase);
    return {
        post: async (route, payload, headers) => {
            let token = await fb.auth.currentUser.getIdToken();
            return await axios.post(route, payload || {}, token ? {
                headers: {
                    ...(headers && { ...headers }),
                    Authorization: token
                }
            } : {});
        },
        put: async (route, payload, headers) => {
            let token = await fb.auth.currentUser.getIdToken();
            return await axios.put(route, payload || {}, token ? {
                headers: {
                    ...(headers && { ...headers }),
                    Authorization: token
                }
            } : {});
        },
        get: async (route, payload, headers) => {
            if (!payload)
                payload = {};
            if (!route)
                return undefined;
            let parameterSlice = [];
            Object.keys(payload).map(key => {
                if (typeof payload[key] === 'object') { //check for apiPayload (input)
                    Object.keys(payload[key]).map(k => parameterSlice = [...parameterSlice, k + "=" + encodeURIComponent(payload[key][k])]);
                }
                else { //don't want to map the object; it doesn't work
                    parameterSlice = [...parameterSlice, key + "=" + encodeURIComponent(payload[key])];
                }
            });
            const query = parameterSlice.join("&");
            let token = await fb.auth.currentUser.getIdToken();
            // get the token from the store
            return await axios.get(route + (route.includes("?") ? "&" : "?") + query, token ? {
                headers: {
                    ...(headers && { ...headers }),
                    Authorization: token
                }
            } : {});
        }
    };
}
export const api = createApi();
