import { get, writable } from "svelte/store";
import { getAnalytics } from "firebase/analytics";
import { initializeApp } from 'firebase/app';
import { createUserWithEmailAndPassword, deleteUser as deleteUserAccount, getAuth, sendEmailVerification, sendPasswordResetEmail, signInWithEmailAndPassword, signOut, updateEmail, updatePassword, updateProfile } from 'firebase/auth';
import { addDoc, collection, deleteDoc, doc, documentId, getDoc, getDocs, getFirestore, query, serverTimestamp, setDoc, updateDoc, where } from 'firebase/firestore';
import { deleteObject, getDownloadURL, getStorage, listAll, ref, uploadBytes } from "firebase/storage";
import { browser } from "$app/environment";
export const firebase = writable({});
if (browser) {
    try {
        let app = initializeApp(JSON.parse(import.meta.env.VITE_FIREBASE_CONFIG), "[DEFAULT]");
        let analytics = getAnalytics(app);
        let firestore = getFirestore(app);
        let auth = getAuth();
        let storage = getStorage();
        firebase.set({
            app, analytics, firestore, auth, storage,
            toDate: (timestamp) => {
                if (!timestamp)
                    return undefined;
                return timestamp["_seconds"] ? new Date(timestamp["_seconds"] * 1000) : new Date(timestamp.seconds * 1000);
            },
            uploadFile: async (data, path) => {
                await uploadBytes(ref(storage, path), data);
                return await getDownloadURL(ref(storage, path));
            },
            getFileURL: async (path) => {
                return await getDownloadURL(ref(storage, path));
            },
            deleteFile: async (path, refer) => {
                const fileRef = refer ? refer : ref(storage, path);
                return await deleteObject(fileRef);
            },
            listFiles: async (path) => {
                const listRef = ref(storage, path);
                const res = await listAll(listRef);
                return res.items;
            },
        });
        console.log("FIREBASE CLIENT INITIALIZED.");
    }
    catch (error) {
        /*
         * We skip the "already exists" message which is
         * not an actual error when we're hot-reloading.
         */
        if (!/duplicate-app/u.test(error.message)) {
            console.error('Firebase initialization error', error.stack);
        }
    }
}
